@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,31 +35,48 @@
  */
 package net.sourceforge.plantuml;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static net.sourceforge.plantuml.utils.CharsetUtils.charsetOrDefault;
+
 import java.io.IOException;
+import java.nio.charset.Charset;
 import java.security.MessageDigest;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 
 import net.sourceforge.plantuml.code.AsciiEncoder;
 import net.sourceforge.plantuml.code.Transcoder;
 import net.sourceforge.plantuml.code.TranscoderUtil;
 import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.core.Diagram;
+import net.sourceforge.plantuml.error.PSystemErrorPreprocessor;
 import net.sourceforge.plantuml.preproc.Defines;
+import net.sourceforge.plantuml.preproc.FileWithSuffix;
+import net.sourceforge.plantuml.preproc2.PreprocessorModeSet;
+import net.sourceforge.plantuml.tim.TimLoader;
 import net.sourceforge.plantuml.utils.StartUtils;
 import net.sourceforge.plantuml.version.Version;
 
 public class BlockUml {
 
-	private final List<CharSequence2> data;
-	private final int startLine;
+	private final List<StringLocated> rawSource;
+	private final List<StringLocated> data;
+	private List<StringLocated> debug;
 	private Diagram system;
 	private final Defines localDefines;
+	private final ISkinSimple skinParam;
+	private final Set<FileWithSuffix> included = new HashSet<>();
+
+	public Set<FileWithSuffix> getIncluded() {
+		return Collections.unmodifiableSet(included);
+	}
 
 	BlockUml(String... strings) {
-		this(convert(strings), 0, Defines.createEmpty());
+		this(convert(strings), Defines.createEmpty(), null, null, null);
 	}
 
 	public String getEncodedUrl() throws IOException {
@@ -71,43 +88,63 @@ public class BlockUml {
 
 	public String getFlashData() {
 		final StringBuilder sb = new StringBuilder();
-		for (CharSequence2 line : data) {
-			sb.append(line);
+		for (StringLocated line : data) {
+			sb.append(line.getString());
 			sb.append('\r');
 			sb.append(BackSlash.CHAR_NEWLINE);
 		}
 		return sb.toString();
 	}
 
-	public static List<CharSequence2> convert(String... strings) {
+	public static List<StringLocated> convert(String... strings) {
 		return convert(Arrays.asList(strings));
 	}
 
-	public static List<CharSequence2> convert(List<String> strings) {
-		final List<CharSequence2> result = new ArrayList<CharSequence2>();
+	public static List<StringLocated> convert(List<String> strings) {
+		final List<StringLocated> result = new ArrayList<>();
 		LineLocationImpl location = new LineLocationImpl("block", null);
 		for (String s : strings) {
 			location = location.oneLineRead();
-			result.add(new CharSequence2Impl(s, location));
+			result.add(new StringLocated(s, location));
 		}
 		return result;
 	}
 
-	public BlockUml(List<CharSequence2> strings, int startLine, Defines defines) {
-		this.startLine = startLine;
+	private boolean preprocessorError;
+
+	/**
+	 * @deprecated being kept for backwards compatibility, perhaps other projects are using this? 
+	 */
+	@Deprecated
+	public BlockUml(List<StringLocated> strings, Defines defines, ISkinSimple skinParam, PreprocessorModeSet mode) {
+		this(strings, defines, skinParam, mode, charsetOrDefault(mode.getCharset()));
+	}
+	
+	public BlockUml(List<StringLocated> strings, Defines defines, ISkinSimple skinParam, PreprocessorModeSet mode, Charset charset) {
+		this.rawSource = new ArrayList<>(strings);
 		this.localDefines = defines;
-		final CharSequence2 s0 = strings.get(0).trin();
+		this.skinParam = skinParam;
+		final String s0 = strings.get(0).getTrimmed().getString();
 		if (StartUtils.startsWithSymbolAnd("start", s0) == false) {
 			throw new IllegalArgumentException();
 		}
-		this.data = new ArrayList<CharSequence2>(strings);
+		if (mode == null) {
+			this.data = new ArrayList<>(strings);
+		} else {
+			final TimLoader timLoader = new TimLoader(mode.getImportedFiles(), defines, charset,
+					(DefinitionsContainer) mode);
+			this.included.addAll(timLoader.load(strings));
+			this.data = timLoader.getResultList();
+			this.debug = timLoader.getDebug();
+			this.preprocessorError = timLoader.isPreprocessorError();
+		}
 	}
 
 	public String getFileOrDirname() {
 		if (OptionFlags.getInstance().isWord()) {
 			return null;
 		}
-		final Matcher2 m = StartUtils.patternFilename.matcher(StringUtils.trin(data.get(0).toString()));
+		final Matcher2 m = StartUtils.patternFilename.matcher(StringUtils.trin(data.get(0).getString()));
 		final boolean ok = m.find();
 		if (ok == false) {
 			return null;
@@ -132,16 +169,16 @@ public class BlockUml {
 
 	public Diagram getDiagram() {
 		if (system == null) {
-			system = new PSystemBuilder().createPSystem(data, startLine);
+			if (preprocessorError) {
+				system = new PSystemErrorPreprocessor(data, debug);
+			} else {
+				system = new PSystemBuilder().createPSystem(skinParam, data, rawSource);
+			}
 		}
 		return system;
 	}
 
-	public final int getStartLine() {
-		return startLine;
-	}
-
-	public final List<CharSequence2> getData() {
+	public final List<StringLocated> getData() {
 		return data;
 	}
 
@@ -149,8 +186,8 @@ public class BlockUml {
 		try {
 			final AsciiEncoder coder = new AsciiEncoder();
 			final MessageDigest msgDigest = MessageDigest.getInstance("MD5");
-			for (CharSequence s : data) {
-				msgDigest.update(s.toString().getBytes("UTF-8"));
+			for (StringLocated s : data) {
+				msgDigest.update(s.getString().getBytes(UTF_8));
 			}
 			final byte[] digest = msgDigest.digest();
 			return coder.encode(digest);
@@ -170,14 +207,18 @@ public class BlockUml {
 
 	public boolean isStartDef(String name) {
 		final String signature = "@startdef(id=" + name + ")";
-		return data.get(0).toString().equalsIgnoreCase(signature);
+		return data.get(0).getString().equalsIgnoreCase(signature);
 	}
 
-	public List<? extends CharSequence> getDefinition(boolean withHeader) {
-		if (withHeader) {
-			return Collections.unmodifiableList(data);
+	public List<String> getDefinition(boolean withHeader) {
+		final List<String> result = new ArrayList<>();
+		for (StringLocated s : data) {
+			result.add(s.getString());
 		}
-		return Collections.unmodifiableList(data.subList(1, data.size() - 1));
+		if (withHeader) {
+			return Collections.unmodifiableList(result);
+		}
+		return Collections.unmodifiableList(result.subList(1, result.size() - 1));
 	}
 
 	public Defines getLocalDefines() {
