@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,9 +35,12 @@
  */
 package net.sourceforge.plantuml;
 
-import java.io.File;
+import static java.util.Objects.requireNonNull;
+import static net.sourceforge.plantuml.utils.CharsetUtils.charsetOrDefault;
+
 import java.io.IOException;
 import java.io.Reader;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
@@ -46,89 +49,100 @@ import java.util.Set;
 
 import net.sourceforge.plantuml.preproc.Defines;
 import net.sourceforge.plantuml.preproc.FileWithSuffix;
-import net.sourceforge.plantuml.preproc.Preprocessor;
+import net.sourceforge.plantuml.preproc.ImportedFiles;
+import net.sourceforge.plantuml.preproc.ReadLineNumbered;
 import net.sourceforge.plantuml.preproc.ReadLineReader;
 import net.sourceforge.plantuml.preproc.UncommentReadLine;
+import net.sourceforge.plantuml.preproc2.Preprocessor;
+import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.utils.StartUtils;
 
 public final class BlockUmlBuilder implements DefinitionsContainer {
 
-	private final List<BlockUml> blocks = new ArrayList<BlockUml>();
-	private Set<FileWithSuffix> usedFiles = new HashSet<FileWithSuffix>();
-	private final UncommentReadLine reader2;
+	private final List<BlockUml> blocks = new ArrayList<>();
+	private Set<FileWithSuffix> usedFiles = new HashSet<>();
+	private final UncommentReadLine reader;
 	private final Defines defines;
+	private final ImportedFiles importedFiles;
+	private final Charset charset;
 
-	public BlockUmlBuilder(List<String> config, String charset, Defines defines, Reader reader, File newCurrentDir,
+	/**
+	 * @deprecated being kept for backwards compatibility, perhaps other projects are using this? 
+	 */
+	@Deprecated
+	public BlockUmlBuilder(List<String> config, String charset, Defines defines, Reader readerInit, SFile newCurrentDir,
 			String desc) throws IOException {
-		Preprocessor includer = null;
+		
+		this(config, charsetOrDefault(charset), defines, readerInit, newCurrentDir, desc);
+	}
+	
+	public BlockUmlBuilder(List<String> config, Charset charset, Defines defines, Reader readerInit, SFile newCurrentDir,
+			String desc) throws IOException {
+		
 		this.defines = defines;
-		try {
-			reader2 = new UncommentReadLine(ReadLineReader.create(reader, desc));
-			includer = new Preprocessor(config, reader2, charset, defines, newCurrentDir, this);
+		this.charset = requireNonNull(charset);
+		this.reader = new UncommentReadLine(ReadLineReader.create(readerInit, desc));
+		this.importedFiles = ImportedFiles.createImportedFiles(new AParentFolderRegular(newCurrentDir));
+		
+		try (ReadLineNumbered includer = new Preprocessor(config, reader)) {
 			init(includer);
 		} finally {
-			if (includer != null) {
-				includer.close();
-				usedFiles = includer.getFilesUsed();
-			}
+			readerInit.close();
 		}
 	}
 
+	/**
+	 * @deprecated being kept for backwards compatibility, perhaps other projects are using this? 
+	 */
+	@Deprecated
 	public BlockUmlBuilder(List<String> config, String charset, Defines defines, Reader reader) throws IOException {
 		this(config, charset, defines, reader, null, null);
 	}
 
-	private void init(Preprocessor includer) throws IOException {
-		CharSequence2 s = null;
-		List<CharSequence2> current2 = null;
+	private void init(ReadLineNumbered includer) throws IOException {
+		StringLocated s = null;
+		List<StringLocated> current = null;
 		boolean paused = false;
-		int startLine = 0;
+
 		while ((s = includer.readLine()) != null) {
-			if (StartUtils.isArobaseStartDiagram(s)) {
-				current2 = new ArrayList<CharSequence2>();
+			if (StartUtils.isArobaseStartDiagram(s.getString())) {
+				current = new ArrayList<>();
 				paused = false;
-				startLine = includer.getLineNumber();
 			}
-			if (StartUtils.isArobasePauseDiagram(s)) {
+			if (StartUtils.isArobasePauseDiagram(s.getString())) {
 				paused = true;
-				reader2.setPaused(true);
+				reader.setPaused(true);
 			}
-			if (StartUtils.isExit(s)) {
+			if (StartUtils.isExit(s.getString())) {
 				paused = true;
-				reader2.setPaused(true);
+				reader.setPaused(true);
 			}
-			if (current2 != null && paused == false) {
-				current2.add(s);
+			if (current != null && paused == false) {
+				current.add(s);
 			} else if (paused) {
-				final CharSequence2 append = StartUtils.getPossibleAppend(s);
+				final StringLocated append = StartUtils.getPossibleAppend(s);
 				if (append != null) {
-					current2.add(append);
+					current.add(append);
 				}
 			}
 
-			if (StartUtils.isArobaseUnpauseDiagram(s)) {
+			if (StartUtils.isArobaseUnpauseDiagram(s.getString())) {
 				paused = false;
-				reader2.setPaused(false);
+				reader.setPaused(false);
 			}
-			if (StartUtils.isArobaseEndDiagram(s) && current2 != null) {
+			if (StartUtils.isArobaseEndDiagram(s.getString()) && current != null) {
 				if (paused) {
-					current2.add(s);
+					current.add(s);
 				}
-				blocks.add(new BlockUml(current2, startLine/* - config.size() */, defines.cloneMe()));
-				current2 = null;
-				reader2.setPaused(false);
+				final BlockUml uml = new BlockUml(current, defines.cloneMe(), null, this, charset);
+				usedFiles.addAll(uml.getIncluded());
+				blocks.add(uml);
+				current = null;
+				reader.setPaused(false);
 			}
 		}
 	}
 
-	// private Collection<CharSequence2> convert(List<String> config, LineLocation location) {
-	// final List<CharSequence2> result = new ArrayList<CharSequence2>();
-	// for (String s : config) {
-	// result.add(new CharSequence2Impl(s, location));
-	// }
-	// return result;
-	// }
-
 	public List<BlockUml> getBlockUmls() {
 		return Collections.unmodifiableList(blocks);
 	}
@@ -137,14 +151,25 @@ public final class BlockUmlBuilder implements DefinitionsContainer {
 		return Collections.unmodifiableSet(usedFiles);
 	}
 
-	public List<? extends CharSequence> getDefinition(String name) {
+	public List<String> getDefinition(String name) {
 		for (BlockUml block : blocks) {
 			if (block.isStartDef(name)) {
-				this.defines.importFrom(block.getLocalDefines());
 				return block.getDefinition(false);
 			}
 		}
 		return Collections.emptyList();
 	}
 
+	public final ImportedFiles getImportedFiles() {
+		return importedFiles;
+	}
+
+	/**
+	 * @deprecated being kept for backwards compatibility, perhaps other projects are using this? 
+	 */
+	@Deprecated
+	public final String getCharset() {
+		return charset.name();
+	}
+
 }
