@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,8 +35,9 @@
  */
 package net.sourceforge.plantuml;
 
-import java.io.File;
-import java.io.FileInputStream;
+import static java.nio.charset.StandardCharsets.UTF_8;
+
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
@@ -49,17 +50,26 @@ import javax.crypto.SecretKeyFactory;
 import javax.crypto.spec.PBEKeySpec;
 
 import net.sourceforge.plantuml.code.AsciiEncoder;
+import net.sourceforge.plantuml.security.SFile;
 
 public class SignatureUtils {
 
-	public static byte[] salting(String pass, byte[] salt) throws NoSuchAlgorithmException, InvalidKeySpecException,
-			UnsupportedEncodingException {
-		final int iterations = 10000;
+	// private static byte[] salting(String pass, byte[] salt) throws
+	// NoSuchAlgorithmException, InvalidKeySpecException,
+	// UnsupportedEncodingException {
+	// final byte[] tmp = salting2(pass, salt);
+	// return SignatureUtils.getSHA512raw(tmp);
+	// }
+
+	public static synchronized byte[] salting(String pass, byte[] salt)
+			throws NoSuchAlgorithmException, InvalidKeySpecException {
+		final int iterations = 500;
 		final int keyLength = 512;
 		final SecretKeyFactory skf = SecretKeyFactory.getInstance("PBKDF2WithHmacSHA1");
 		final PBEKeySpec spec = new PBEKeySpec(pass.toCharArray(), salt, iterations, keyLength);
 		final SecretKey key = skf.generateSecret(spec);
-		return SignatureUtils.getSHA512raw(key.getEncoded());
+		final byte[] tmp = key.getEncoded();
+		return tmp;
 	}
 
 	public static String getSignature(String s) {
@@ -116,32 +126,31 @@ public class SignatureUtils {
 		}
 	}
 
-	public static byte[] getMD5raw(String s) throws NoSuchAlgorithmException, UnsupportedEncodingException {
+	public static synchronized byte[] getMD5raw(String s)
+			throws NoSuchAlgorithmException, UnsupportedEncodingException {
 		final MessageDigest msgDigest = MessageDigest.getInstance("MD5");
-		msgDigest.update(s.getBytes("UTF-8"));
+		msgDigest.update(s.getBytes(UTF_8));
 		return msgDigest.digest();
 	}
 
 	public static byte[] getSHA512raw(String s) throws NoSuchAlgorithmException, UnsupportedEncodingException {
-		return getSHA512raw(s.getBytes("UTF-8"));
+		return getSHA512raw(s.getBytes(UTF_8));
 	}
 
-	public static byte[] getSHA512raw(byte data[]) throws NoSuchAlgorithmException, UnsupportedEncodingException {
+	public static synchronized byte[] getSHA512raw(byte data[])
+			throws NoSuchAlgorithmException, UnsupportedEncodingException {
 		final MessageDigest msgDigest = MessageDigest.getInstance("SHA-512");
 		msgDigest.update(data);
 		return msgDigest.digest();
 	}
 
-	public static String getSignatureSha512(File f) throws IOException {
-		final InputStream is = new FileInputStream(f);
-		try {
+	public static String getSignatureSha512(SFile f) throws IOException {
+		try (InputStream is = f.openFile()) {
 			return getSignatureSha512(is);
-		} finally {
-			is.close();
 		}
 	}
 
-	public static String getSignatureSha512(InputStream is) throws IOException {
+	public static synchronized String getSignatureSha512(InputStream is) throws IOException {
 		try {
 			final MessageDigest msgDigest = MessageDigest.getInstance("SHA-512");
 			int read = 0;
@@ -172,15 +181,16 @@ public class SignatureUtils {
 		return s;
 	}
 
-	public static String getSignature(File f) throws IOException {
-		try {
+	public static synchronized String getSignature(SFile f) throws IOException {
+		try (final InputStream is = f.openFile()) {
 			final MessageDigest msgDigest = MessageDigest.getInstance("MD5");
-			final FileInputStream is = new FileInputStream(f);
+			if (is == null) {
+				throw new FileNotFoundException();
+			}
 			int read = -1;
 			while ((read = is.read()) != -1) {
 				msgDigest.update((byte) read);
 			}
-			is.close();
 			final byte[] digest = msgDigest.digest();
 			return toString(digest);
 		} catch (NoSuchAlgorithmException e) {
