@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -30,12 +30,14 @@
  *
  *
  * Original Author:  Arnaud Roques
+ * Contribution :  Hisashi Miyashita
  * 
  *
  */
 package net.sourceforge.plantuml.classdiagram.command;
 
 import net.sourceforge.plantuml.FontParam;
+import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.UrlBuilder;
@@ -45,11 +47,13 @@ import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
 import net.sourceforge.plantuml.command.regex.RegexConcat;
 import net.sourceforge.plantuml.command.regex.RegexLeaf;
+import net.sourceforge.plantuml.command.regex.RegexOptional;
 import net.sourceforge.plantuml.command.regex.RegexOr;
 import net.sourceforge.plantuml.command.regex.RegexResult;
 import net.sourceforge.plantuml.cucadiagram.Code;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.IEntity;
+import net.sourceforge.plantuml.cucadiagram.Ident;
 import net.sourceforge.plantuml.cucadiagram.LeafType;
 import net.sourceforge.plantuml.cucadiagram.Stereotag;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
@@ -57,6 +61,7 @@ import net.sourceforge.plantuml.descdiagram.command.CommandCreateElementFull;
 import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.graphic.color.ColorParser;
 import net.sourceforge.plantuml.graphic.color.ColorType;
+import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
 
 public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram> {
 
@@ -72,35 +77,72 @@ public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram>
 	}
 
 	private static RegexConcat getRegexConcat(Mode mode) {
-
-		// String regex = "(?:(actor|usecase|component)[%s]+)";
-		String regex = "(?:(state|" + CommandCreateElementFull.ALL_TYPES + ")[%s]+)";
+		String regex = "(state|" + CommandCreateElementFull.ALL_TYPES + ")";
 		if (mode == Mode.WITH_MIX_PREFIX) {
-			regex = "mix_" + regex;
+			return RegexConcat.build(CommandCreateElementFull2.class.getName() + mode, //
+					RegexLeaf.start(), //
+					new RegexLeaf("mix_"), //
+					new RegexLeaf("SYMBOL", regex), //
+					RegexLeaf.spaceOneOrMore(), //
+					new RegexOr(//
+							new RegexLeaf("CODE1", CommandCreateElementFull.CODE_WITH_QUOTE), //
+							new RegexConcat(//
+									new RegexLeaf("DISPLAY2", CommandCreateElementFull.DISPLAY), //
+									new RegexOptional( //
+											new RegexConcat( //
+													RegexLeaf.spaceOneOrMore(), //
+													new RegexLeaf("STEREOTYPE2", "(\\<\\<.+\\>\\>)") //
+											)), //
+									RegexLeaf.spaceZeroOrMore(), //
+									new RegexLeaf("as"), //
+									RegexLeaf.spaceOneOrMore(), //
+									new RegexLeaf("CODE2", CommandCreateElementFull.CODE)) //
+					), //
+					new RegexOptional( //
+							new RegexConcat( //
+									RegexLeaf.spaceZeroOrMore(), //
+									new RegexLeaf("STEREOTYPE", "(\\<\\<.+\\>\\>)")//
+							)), //
+					RegexLeaf.spaceZeroOrMore(), //
+					new RegexLeaf("TAGS", Stereotag.pattern() + "?"), //
+					RegexLeaf.spaceZeroOrMore(), //
+					new RegexLeaf("URL", "(" + UrlBuilder.getRegexp() + ")?"), //
+					RegexLeaf.spaceZeroOrMore(), //
+					ColorParser.exp1(), //
+					RegexLeaf.end());
 		}
-		return new RegexConcat(new RegexLeaf("^"), //
+		return RegexConcat.build(CommandCreateElementFull2.class.getName() + mode, //
+				RegexLeaf.start(), //
 				new RegexLeaf("SYMBOL", regex), //
-				new RegexLeaf("[%s]*"), //
+				RegexLeaf.spaceOneOrMore(), //
 				new RegexOr(//
 						new RegexLeaf("CODE1", CommandCreateElementFull.CODE_WITH_QUOTE), //
 						new RegexConcat(//
 								new RegexLeaf("DISPLAY2", CommandCreateElementFull.DISPLAY), //
-								new RegexLeaf("STEREOTYPE2", "(?:[%s]+(\\<\\<.+\\>\\>))?"), //
-								new RegexLeaf("[%s]*as[%s]+"), //
+								new RegexOptional( //
+										new RegexConcat( //
+												RegexLeaf.spaceOneOrMore(), //
+												new RegexLeaf("STEREOTYPE2", "(\\<\\<.+\\>\\>)") //
+										)), //
+								RegexLeaf.spaceZeroOrMore(), //
+								new RegexLeaf("as"), //
+								RegexLeaf.spaceOneOrMore(), //
 								new RegexLeaf("CODE2", CommandCreateElementFull.CODE)) //
 				), //
-				new RegexLeaf("STEREOTYPE", "(?:[%s]*(\\<\\<.+\\>\\>))?"), //
-				new RegexLeaf("[%s]*"), //
+				new RegexOptional( //
+						new RegexConcat( //
+								RegexLeaf.spaceZeroOrMore(), //
+								new RegexLeaf("STEREOTYPE", "(\\<\\<.+\\>\\>)")//
+						)), //
+				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf("TAGS", Stereotag.pattern() + "?"), //
-				new RegexLeaf("[%s]*"), //
+				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf("URL", "(" + UrlBuilder.getRegexp() + ")?"), //
-				new RegexLeaf("[%s]*"), //
+				RegexLeaf.spaceZeroOrMore(), //
 				ColorParser.exp1(), //
-				new RegexLeaf("$"));
+				RegexLeaf.end());
 	}
 
-
-
 	@Override
 	final protected boolean isForbidden(CharSequence line) {
 		if (line.toString().matches("^[\\p{L}0-9_.]+$")) {
@@ -110,10 +152,10 @@ public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram>
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(ClassDiagram diagram, RegexResult arg) {
+	protected CommandExecutionResult executeArg(ClassDiagram diagram, LineLocation location, RegexResult arg)
+			throws NoSuchColorException {
 		if (mode == Mode.NORMAL_KEYWORD && diagram.isAllowMixing() == false) {
-			return CommandExecutionResult
-					.error("Use 'allow_mixing' if you want to mix classes and other UML elements.");
+			return CommandExecutionResult.error("Use 'allowmixing' if you want to mix classes and other UML elements.");
 		}
 		String codeRaw = arg.getLazzy("CODE", 0);
 		final String displayRaw = arg.getLazzy("DISPLAY", 0);
@@ -138,7 +180,10 @@ public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram>
 
 		if (symbol == null) {
 			type = LeafType.DESCRIPTION;
-			usymbol = USymbol.ACTOR;
+			usymbol = diagram.getSkinParam().actorStyle().toUSymbol();
+		} else if (symbol.equalsIgnoreCase("port")) {
+			type = LeafType.PORT;
+			usymbol = null;
 		} else if (symbol.equalsIgnoreCase("usecase")) {
 			type = LeafType.USECASE;
 			usymbol = null;
@@ -147,26 +192,28 @@ public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram>
 			usymbol = null;
 		} else {
 			type = LeafType.DESCRIPTION;
-			usymbol = USymbol.getFromString(symbol, diagram.getSkinParam().useUml2ForComponent());
+			usymbol = USymbol.fromString(symbol, diagram.getSkinParam());
 			if (usymbol == null) {
 				throw new IllegalStateException();
 			}
 		}
 
-		final Code code = Code.of(StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(codeRaw));
+		final String idShort = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(codeRaw);
+		final Ident ident = diagram.buildLeafIdent(idShort);
+		final Code code = diagram.V1972() ? ident : diagram.buildCode(idShort);
 		String display = displayRaw;
 		if (display == null) {
-			display = code.getFullName();
+			display = code.getName();
 		}
 		display = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(display);
 		final String stereotype = arg.getLazzy("STEREOTYPE", 0);
-		final IEntity entity = diagram.getOrCreateLeaf(code, type, usymbol);
+		final IEntity entity = diagram.getOrCreateLeaf(ident, code, type, usymbol);
 		entity.setDisplay(Display.getWithNewlines(display));
 		entity.setUSymbol(usymbol);
 		if (stereotype != null) {
-			entity.setStereotype(new Stereotype(stereotype, diagram.getSkinParam().getCircledCharacterRadius(), diagram
-					.getSkinParam().getFont(null, false, FontParam.CIRCLED_CHARACTER), diagram.getSkinParam()
-					.getIHtmlColorSet()));
+			entity.setStereotype(Stereotype.build(stereotype, diagram.getSkinParam().getCircledCharacterRadius(),
+					diagram.getSkinParam().getFont(null, false, FontParam.CIRCLED_CHARACTER),
+					diagram.getSkinParam().getIHtmlColorSet()));
 		}
 		CommandCreateClassMultilines.addTags(entity, arg.get("TAGS", 0));
 
@@ -176,9 +223,10 @@ public class CommandCreateElementFull2 extends SingleLineCommand2<ClassDiagram>
 			final Url url = urlBuilder.getUrl(urlString);
 			entity.addUrl(url);
 		}
+		final String s = arg.get("COLOR", 0);
 
-		entity.setSpecificColorTOBEREMOVED(ColorType.BACK,
-				diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(arg.get("COLOR", 0)));
+		entity.setSpecificColorTOBEREMOVED(ColorType.BACK, s == null ? null
+				: diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), s));
 		return CommandExecutionResult.ok();
 	}
 
