@@ -36,6 +36,8 @@
 package net.sourceforge.plantuml.core;
 
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -147,6 +149,10 @@ final public class UmlSource {
 		return new IteratorCounter2Impl(source);
 	}
 
+//	public Iterator<StringLocated> iteratorRaw() {
+//		return Collections.unmodifiableCollection(rawSource).iterator();
+//	}
+
 	/**
 	 * Return the source as a single String with <code>\n</code> as line separator.
 	 * 
