@@ -124,20 +124,20 @@ public final class EntityFactory {
 		final USymbol symbol = g.getUSymbol();
 		folder.setUSymbol(symbol);
 		folder.setStereotype(g.getStereotype());
-		folder.setColors(g.getColors(skinParam));
+		folder.setColors(g.getColors());
 		if (g.getUrl99() != null) {
 			folder.addUrl(g.getUrl99());
 		}
 		if (UseStyle.useBetaStyle()) {
 			// System.err.println("Backcolor ?");
 		} else {
-			if (g.getColors(skinParam).getColor(ColorType.BACK) == null) {
+			if (g.getColors().getColor(ColorType.BACK) == null) {
 				final ColorParam param = symbol == null ? ColorParam.packageBackground : symbol.getColorParamBack();
 				final HColor c1 = skinParam.getHtmlColor(param, g.getStereotype(), false);
 				folder.setSpecificColorTOBEREMOVED(ColorType.BACK,
 						c1 == null ? skinParam.getBackgroundColor() : c1);
 			} else {
-				folder.setSpecificColorTOBEREMOVED(ColorType.BACK, g.getColors(skinParam).getColor(ColorType.BACK));
+				folder.setSpecificColorTOBEREMOVED(ColorType.BACK, g.getColors().getColor(ColorType.BACK));
 			}
 		}
 		emptyGroupsAsNode.put(g, folder);
