@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,111 +35,136 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.Font;
 import java.awt.geom.Dimension2D;
 import java.awt.image.BufferedImage;
 import java.util.List;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.SpriteContainerEmpty;
+import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.svek.IEntityImage;
 import net.sourceforge.plantuml.svek.Margins;
 import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.svek.TextBlockBackcolored;
-import net.sourceforge.plantuml.ugraphic.UChangeColor;
+import net.sourceforge.plantuml.ugraphic.AffineTransformType;
+import net.sourceforge.plantuml.ugraphic.PixelImage;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UImage;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
 public class GraphicStrings extends AbstractTextBlock implements IEntityImage {
 
 	private final double margin = 5;
 
-	private final HtmlColor background;
+	private final HColor background;
 
-	private final UFont font;
+	private final static HColor hyperlinkColor = HColorUtils.BLUE;
 
-	private final HtmlColor maincolor;
-
-	private final HtmlColor hyperlinkColor = HtmlColorUtils.BLUE;
-
-	private final boolean useUnderlineForHyperlink = true;
+	private final static boolean useUnderlineForHyperlink = true;
 
 	private final List<String> strings;
 
 	private final BufferedImage image;
+	private final double imagePadding = 30;
 
 	private final GraphicPosition position;
 
+	private final FontConfiguration fontConfiguration;
+
 	public static IEntityImage createForError(List<String> strings, boolean useRed) {
+		return new GraphicStrings(strings, sansSerif14(getForeColor(useRed)).bold(), getBackColor(useRed), null, null,
+				CreoleMode.NO_CREOLE);
+	}
+
+	private static HColor getForeColor(boolean useRed) {
 		if (useRed) {
-			return new GraphicStrings(strings, UFont.sansSerif(14).bold(), HtmlColorUtils.BLACK,
-					HtmlColorUtils.RED_LIGHT, null, null);
+			return HColorUtils.BLACK;
 		}
-		return new GraphicStrings(strings, UFont.sansSerif(14).bold(), HtmlColorSet.getInstance().getColorIfValid(
-				"#33FF02"), HtmlColorUtils.BLACK, null, null);
+		return HColorUtils.MY_GREEN;
+	}
+
+	private static HColor getBackColor(boolean useRed) {
+		if (useRed) {
+			return HColorUtils.RED_LIGHT;
+		}
+		return HColorUtils.BLACK;
 	}
 
 	public static TextBlockBackcolored createGreenOnBlackMonospaced(List<String> strings) {
-		return new GraphicStrings(strings, monospaced14(), HtmlColorUtils.GREEN, HtmlColorUtils.BLACK, null, null);
+		return new GraphicStrings(strings, monospaced14(HColorUtils.GREEN), HColorUtils.BLACK, null, null,
+				CreoleMode.SIMPLE_LINE);
 	}
 
 	public static TextBlockBackcolored createBlackOnWhite(List<String> strings) {
-		return new GraphicStrings(strings, sansSerif12(), HtmlColorUtils.BLACK, HtmlColorUtils.WHITE, null, null);
+		return new GraphicStrings(strings, sansSerif12(HColorUtils.BLACK), HColorUtils.WHITE, null, null,
+				CreoleMode.FULL);
 	}
 
 	public static TextBlockBackcolored createBlackOnWhiteMonospaced(List<String> strings) {
-		return new GraphicStrings(strings, monospaced14(), HtmlColorUtils.BLACK, HtmlColorUtils.WHITE, null, null);
+		return new GraphicStrings(strings, monospaced14(HColorUtils.BLACK), HColorUtils.WHITE, null, null,
+				CreoleMode.FULL);
 	}
 
 	public static TextBlockBackcolored createBlackOnWhite(List<String> strings, BufferedImage image,
 			GraphicPosition position) {
-		return new GraphicStrings(strings, sansSerif12(), HtmlColorUtils.BLACK, HtmlColorUtils.WHITE, image, position);
+		return new GraphicStrings(strings, sansSerif12(HColorUtils.BLACK), HColorUtils.WHITE, image, position,
+				CreoleMode.FULL);
 	}
 
-	private static UFont sansSerif12() {
-		return UFont.sansSerif(12);
+	public static FontConfiguration sansSerif12(HColor color) {
+		return new FontConfiguration(UFont.sansSerif(12), color, hyperlinkColor, useUnderlineForHyperlink);
 	}
 
-	private static UFont monospaced14() {
-		return UFont.monospaced(14);
+	public static FontConfiguration sansSerif14(HColor color) {
+		return new FontConfiguration(UFont.sansSerif(14), color, hyperlinkColor, useUnderlineForHyperlink);
 	}
 
-	private GraphicStrings(List<String> strings, UFont font, HtmlColor maincolor, HtmlColor background,
-			BufferedImage image, GraphicPosition position) {
+	private static FontConfiguration monospaced14(HColor color) {
+		return new FontConfiguration(UFont.monospaced(14), color, hyperlinkColor, useUnderlineForHyperlink);
+	}
+
+	private final CreoleMode mode;
+
+	private GraphicStrings(List<String> strings, FontConfiguration fontConfiguration, HColor background,
+			BufferedImage image, GraphicPosition position, CreoleMode mode) {
 		this.strings = strings;
-		this.font = font;
-		this.maincolor = maincolor;
 		this.background = background;
 		this.image = image;
 		this.position = position;
+		this.mode = mode;
+		this.fontConfiguration = fontConfiguration;
+
 	}
 
 	private TextBlock getTextBlock() {
-		TextBlock result = null;
-		result = Display.create(strings).create(
-				new FontConfiguration(font, maincolor, hyperlinkColor, useUnderlineForHyperlink),
-				HorizontalAlignment.LEFT, new SpriteContainerEmpty());
-		// result = DateEventUtils.addEvent(result, green);
-		return result;
+		final Display display = Display.create(strings);
+		if (mode == CreoleMode.NO_CREOLE) {
+			return new TextBlockRaw(strings, fontConfiguration);
+
+		} else {
+			return display.create7(fontConfiguration, HorizontalAlignment.LEFT, new SpriteContainerEmpty(), mode);
+		}
 	}
 
 	public void drawU(UGraphic ug) {
 		ug = ug.apply(new UTranslate(margin, margin));
 		final Dimension2D size = calculateDimensionInternal(ug.getStringBounder());
-		getTextBlock().drawU(ug.apply(new UChangeColor(maincolor)));
+		getTextBlock().drawU(ug.apply(fontConfiguration.getColor()));
 
 		if (image != null) {
 			if (position == GraphicPosition.BOTTOM) {
 				ug.apply(new UTranslate((size.getWidth() - image.getWidth()) / 2, size.getHeight() - image.getHeight()))
-						.draw(new UImage(image));
+						.draw(new UImage(new PixelImage(image, AffineTransformType.TYPE_BILINEAR)));
 			} else if (position == GraphicPosition.BACKGROUND_CORNER_BOTTOM_RIGHT) {
 				ug.apply(new UTranslate(size.getWidth() - image.getWidth(), size.getHeight() - image.getHeight()))
-						.draw(new UImage(image));
+						.draw(new UImage(new PixelImage(image, AffineTransformType.TYPE_BILINEAR)));
 			} else if (position == GraphicPosition.BACKGROUND_CORNER_TOP_RIGHT) {
-				ug.apply(new UTranslate(size.getWidth() - image.getWidth() - 1, 1)).draw(new UImage(image));
+				ug.apply(new UTranslate(size.getWidth() - image.getWidth() - 1, 1))
+						.draw(new UImage(new PixelImage(image, AffineTransformType.TYPE_BILINEAR)));
 			}
 		}
 	}
@@ -154,9 +179,9 @@ public class GraphicStrings extends AbstractTextBlock implements IEntityImage {
 			if (position == GraphicPosition.BOTTOM) {
 				dim = new Dimension2DDouble(dim.getWidth(), dim.getHeight() + image.getHeight());
 			} else if (position == GraphicPosition.BACKGROUND_CORNER_BOTTOM_RIGHT) {
-				dim = new Dimension2DDouble(dim.getWidth() + image.getWidth(), dim.getHeight());
+				dim = new Dimension2DDouble(dim.getWidth() + imagePadding + image.getWidth(), dim.getHeight());
 			} else if (position == GraphicPosition.BACKGROUND_CORNER_TOP_RIGHT) {
-				dim = new Dimension2DDouble(dim.getWidth() + image.getWidth(), dim.getHeight());
+				dim = new Dimension2DDouble(dim.getWidth() + imagePadding + image.getWidth(), dim.getHeight());
 			}
 		}
 		return dim;
@@ -166,7 +191,7 @@ public class GraphicStrings extends AbstractTextBlock implements IEntityImage {
 		return ShapeType.RECTANGLE;
 	}
 
-	public HtmlColor getBackcolor() {
+	public HColor getBackcolor() {
 		return background;
 	}
 
@@ -178,4 +203,8 @@ public class GraphicStrings extends AbstractTextBlock implements IEntityImage {
 		return false;
 	}
 
+	public double getOverscanX(StringBounder stringBounder) {
+		return 0;
+	}
+
 }
