@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,43 +35,62 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.Font;
-import java.awt.FontMetrics;
-import java.awt.Graphics2D;
 import java.awt.font.FontRenderContext;
-import java.awt.font.LineMetrics;
+import java.awt.font.TextLayout;
 import java.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
-import java.awt.image.BufferedImage;
 
 import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.CornerParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineParam;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.posimo.Positionable;
 import net.sourceforge.plantuml.posimo.PositionableImpl;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
+import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 import net.sourceforge.plantuml.ugraphic.LimitFinder;
 import net.sourceforge.plantuml.ugraphic.MinMax;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
+import net.sourceforge.plantuml.ugraphic.UImage;
 import net.sourceforge.plantuml.ugraphic.UStroke;
+import net.sourceforge.plantuml.ugraphic.UText;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
 public class TextBlockUtils {
 
-	public static TextBlock bordered(TextBlock textBlock, UStroke stroke, HtmlColor borderColor,
-			HtmlColor backgroundColor, double cornersize) {
+	public static final TextBlock EMPTY_TEXT_BLOCK = TextBlockUtils.empty(0, 0);
+
+	public static TextBlock bordered(TextBlock textBlock, UStroke stroke, HColor borderColor, HColor backgroundColor,
+			double cornersize) {
 		return new TextBlockBordered(textBlock, stroke, borderColor, backgroundColor, cornersize);
 	}
 
+	public static TextBlock bordered(TextBlock textBlock, UStroke stroke, HColor borderColor, HColor backgroundColor,
+			double cornersize, double marginX, double marginY) {
+		return new TextBlockBordered(textBlock, stroke, borderColor, backgroundColor, cornersize, marginX, marginY);
+	}
+
+	public static TextBlock bordered(TextBlock textBlock, UStroke stroke, HColor borderColor, HColor backgroundColor,
+			double cornersize, ClockwiseTopRightBottomLeft margins) {
+		return new TextBlockBordered(textBlock, stroke, borderColor, backgroundColor, cornersize, margins);
+	}
+
 	public static TextBlock title(FontConfiguration font, Display stringsToDisplay, ISkinParam skinParam) {
+		if (UseStyle.useBetaStyle()) {
+			throw new UnsupportedOperationException();
+		}
 		UStroke stroke = skinParam.getThickness(LineParam.titleBorder, null);
 		final Rose rose = new Rose();
-		HtmlColor borderColor = rose.getHtmlColor(skinParam, ColorParam.titleBorder);
-		final HtmlColor backgroundColor = rose.getHtmlColor(skinParam, ColorParam.titleBackground);
+		HColor borderColor = rose.getHtmlColor(skinParam, ColorParam.titleBorder);
+		final HColor backgroundColor = rose.getHtmlColor(skinParam, ColorParam.titleBackground);
 		final TextBlockTitle result = new TextBlockTitle(font, stringsToDisplay, skinParam);
 		if (stroke == null && borderColor == null) {
 			return result;
@@ -80,22 +99,30 @@ public class TextBlockUtils {
 			stroke = new UStroke(1.5);
 		}
 		if (borderColor == null) {
-			borderColor = HtmlColorUtils.BLACK;
+			borderColor = HColorUtils.BLACK;
 		}
 		final double corner = skinParam.getRoundCorner(CornerParam.titleBorder, null);
 		return withMargin(bordered(result, stroke, borderColor, backgroundColor, corner), 2, 2);
 	}
 
 	public static TextBlock withMargin(TextBlock textBlock, double marginX, double marginY) {
-		return new TextBlockMarged(textBlock, marginX, marginX, marginY, marginY);
+		if (marginX == 0 && marginY == 0) {
+			return textBlock;
+		}
+		return new TextBlockMarged(textBlock, marginY, marginX, marginY, marginX);
+	}
+
+	public static TextBlock withMargin(TextBlock textBlock, ClockwiseTopRightBottomLeft margins) {
+		return new TextBlockMarged(textBlock, margins);
 	}
 
 	public static TextBlock withMargin(TextBlock textBlock, double marginX1, double marginX2, double marginY1,
 			double marginY2) {
-		return new TextBlockMarged(textBlock, marginX1, marginX2, marginY1, marginY2);
+		return new TextBlockMarged(textBlock, marginY1, marginX2, marginY2, marginX1);
 	}
 
-	public static TextBlock withMinWidth(TextBlock textBlock, double minWidth, HorizontalAlignment horizontalAlignment) {
+	public static TextBlock withMinWidth(TextBlock textBlock, double minWidth,
+			HorizontalAlignment horizontalAlignment) {
 		return new TextBlockMinWidth(textBlock, minWidth, horizontalAlignment);
 	}
 
@@ -107,6 +134,11 @@ public class TextBlockUtils {
 			public Dimension2D calculateDimension(StringBounder stringBounder) {
 				return new Dimension2DDouble(width, height);
 			}
+
+			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+				return null;
+			}
+
 		};
 	}
 
@@ -114,25 +146,47 @@ public class TextBlockUtils {
 		return new PositionableImpl(pt, textBlock.calculateDimension(stringBounder));
 	}
 
+	public static Positionable asPositionable(Dimension2D dim, StringBounder stringBounder, Point2D pt) {
+		return new PositionableImpl(pt, dim);
+	}
+
 	public static TextBlock mergeLR(TextBlock b1, TextBlock b2, VerticalAlignment verticallAlignment) {
+		if (b1 == EMPTY_TEXT_BLOCK) {
+			return b2;
+		}
+		if (b2 == EMPTY_TEXT_BLOCK) {
+			return b1;
+		}
 		return new TextBlockHorizontal(b1, b2, verticallAlignment);
 	}
 
 	public static TextBlock mergeTB(TextBlock b1, TextBlock b2, HorizontalAlignment horizontalAlignment) {
+		if (b1 == EMPTY_TEXT_BLOCK) {
+			return b2;
+		}
+		if (b2 == EMPTY_TEXT_BLOCK) {
+			return b1;
+		}
 		return new TextBlockVertical2(b1, b2, horizontalAlignment);
 	}
 
-	public static MinMax getMinMax(TextBlock tb, StringBounder stringBounder) {
-		final LimitFinder limitFinder = new LimitFinder(stringBounder, false);
-		tb.drawU(limitFinder);
-		return limitFinder.getMinMax();
+	public static TextBlock mergeTB(TextBlock b1, UImage image, HorizontalAlignment horizontalAlignment) {
+		if (b1 == EMPTY_TEXT_BLOCK) {
+			throw new IllegalArgumentException();
+		}
+		return new TextBlockVertical2(b1, image, horizontalAlignment);
 	}
 
-	private static final Graphics2D gg;
+	// public static TextBlockBackcolored mergeColoredTB(TextBlockBackcolored b1,
+	// TextBlockBackcolored b2,
+	// HorizontalAlignment horizontalAlignment) {
+	// return addBackcolor(mergeTB(b1, b2, horizontalAlignment), b1.getBackcolor());
+	// }
 
-	static {
-		final BufferedImage imDummy = new BufferedImage(10, 10, BufferedImage.TYPE_INT_RGB);
-		gg = imDummy.createGraphics();
+	public static MinMax getMinMax(UDrawable tb, StringBounder stringBounder, boolean initToZero) {
+		final LimitFinder limitFinder = new LimitFinder(stringBounder, initToZero);
+		tb.drawU(limitFinder);
+		return limitFinder.getMinMax();
 	}
 
 	public static boolean isEmpty(TextBlock text, StringBounder dummyStringBounder) {
@@ -144,15 +198,15 @@ public class TextBlockUtils {
 	}
 
 	public static FontRenderContext getFontRenderContext() {
-		return gg.getFontRenderContext();
+		return FileFormat.gg.getFontRenderContext();
 	}
 
-	public static LineMetrics getLineMetrics(UFont font, String text) {
-		return font.getLineMetrics(gg, text);
+	public static TextLayout createTextLayout(UText shape) {
+		return createTextLayout(shape.getFontConfiguration().getFont(), shape.getText());
 	}
 
-	public static FontMetrics getFontMetrics(Font font) {
-		return gg.getFontMetrics(font);
+	public static TextLayout createTextLayout(UFont font, String string) {
+		return new TextLayout(string, font.getUnderlayingFont(), getFontRenderContext());
 	}
 
 	public static TextBlock fullInnerPosition(final TextBlock bloc, final String display) {
@@ -165,7 +219,7 @@ public class TextBlockUtils {
 			public Dimension2D calculateDimension(StringBounder stringBounder) {
 				return bloc.calculateDimension(stringBounder);
 			}
-			
+
 			public MinMax getMinMax(StringBounder stringBounder) {
 				return bloc.getMinMax(stringBounder);
 			}
@@ -181,4 +235,50 @@ public class TextBlockUtils {
 		};
 	}
 
+	public static TextBlockBackcolored addBackcolor(final TextBlock text, final HColor backColor) {
+		return new TextBlockBackcolored() {
+			public void drawU(UGraphic ug) {
+				text.drawU(ug);
+			}
+
+			public MinMax getMinMax(StringBounder stringBounder) {
+				return text.getMinMax(stringBounder);
+			}
+
+			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+				return text.getInnerPosition(member, stringBounder, strategy);
+			}
+
+			public Dimension2D calculateDimension(StringBounder stringBounder) {
+				return text.calculateDimension(stringBounder);
+			}
+
+			public HColor getBackcolor() {
+				return backColor;
+			}
+		};
+	}
+
+	public static TextBlock fromUImage(final UImage image) {
+		return new TextBlock() {
+
+			public void drawU(UGraphic ug) {
+				ug.draw(image);
+			}
+
+			public Dimension2D calculateDimension(StringBounder stringBounder) {
+				return new Dimension2DDouble(image.getWidth(), image.getHeight());
+			}
+
+			public MinMax getMinMax(StringBounder stringBounder) {
+				return MinMax.fromMax(image.getWidth(), image.getHeight());
+			}
+
+			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+				return null;
+			}
+
+		};
+	}
+
 }
