@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -149,14 +149,14 @@ public class ParticipantBox implements Pushable {
 		// ug.translate(outMargin, 0);
 		final StringBounder stringBounder = ug.getStringBounder();
 		head.drawU(
-				ug.apply(new UTranslate(outMargin, 0)),
+				ug.apply(UTranslate.dx(outMargin)),
 				new Area(new Dimension2DDouble(head.getPreferredWidth(stringBounder), head
 						.getPreferredHeight(stringBounder))), new SimpleContext2D(false));
 		// ug.translate(-outMargin, 0);
 	}
 
 	public void drawLineU22(UGraphic ug, double startingY, final double endingY, boolean showTail, double myDelta) {
-		ug = ug.apply(new UTranslate(startingX, 0));
+		ug = ug.apply(UTranslate.dx(startingX));
 		if (delays.size() > 0) {
 			final StringBounder stringBounder = ug.getStringBounder();
 			for (GraphicalDelayText delay : delays) {
@@ -185,7 +185,7 @@ public class ParticipantBox implements Pushable {
 
 	private void drawLine(UGraphic ug, double startingY, double endingY, Component comp) {
 		final StringBounder stringBounder = ug.getStringBounder();
-		comp.drawU(ug.apply(new UTranslate(0, startingY)),
+		comp.drawU(ug.apply(UTranslate.dy(startingY)),
 				new Area(new Dimension2DDouble(head.getPreferredWidth(stringBounder) + outMargin * 2, endingY
 						- startingY)), new SimpleContext2D(false));
 	}
@@ -198,7 +198,7 @@ public class ParticipantBox implements Pushable {
 		return startingX;
 	}
 
-	private final List<GraphicalDelayText> delays = new ArrayList<GraphicalDelayText>();
+	private final List<GraphicalDelayText> delays = new ArrayList<>();
 
 	public void addDelay(GraphicalDelayText delay) {
 		this.delays.add(delay);
