@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -43,25 +43,32 @@ import java.util.TreeMap;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.sequencediagram.Delay;
 import net.sourceforge.plantuml.sequencediagram.Event;
+import net.sourceforge.plantuml.sequencediagram.Participant;
 import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.skin.Component;
 import net.sourceforge.plantuml.skin.ComponentType;
 import net.sourceforge.plantuml.skin.Context2D;
-import net.sourceforge.plantuml.skin.Skin;
+import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 public class MutingLine {
 
-	private final Skin skin;
+	private final Rose skin;
 	private final ISkinParam skinParam;
 	private final boolean useContinueLineBecauseOfDelay;
 	private final Map<Double, Double> delays = new TreeMap<Double, Double>();
+	private final StyleBuilder styleBuilder;
+	private final Participant participant;
 
-	public MutingLine(Skin skin, ISkinParam skinParam, List<Event> events) {
+	public MutingLine(Rose skin, ISkinParam skinParam, List<Event> events, Participant participant) {
+		this.participant = participant;
 		this.skin = skin;
 		this.skinParam = skinParam;
 		this.useContinueLineBecauseOfDelay = useContinueLineBecauseOfDelay(events);
+		this.styleBuilder = skinParam.getCurrentStyleBuilder();
 	}
 
 	private boolean useContinueLineBecauseOfDelay(List<Event> events) {
@@ -95,17 +102,20 @@ public class MutingLine {
 		}
 	}
 
-	private void drawInternal(UGraphic ug, Context2D context, double y1, double y2, final ComponentType defaultLineType) {
+	private void drawInternal(UGraphic ug, Context2D context, double y1, double y2,
+			final ComponentType defaultLineType) {
 		if (y2 == y1) {
 			return;
 		}
 		if (y2 < y1) {
 			throw new IllegalArgumentException();
 		}
-		final Component comp = skin.createComponent(defaultLineType, null, skinParam, null);
+		final Style style = defaultLineType.getDefaultStyleDefinition().getMergedStyle(styleBuilder);
+		final Component comp = skin.createComponent(new Style[] { style }, defaultLineType, null, skinParam,
+				participant.getDisplay(skinParam.forceSequenceParticipantUnderlined()));
 		final Dimension2D dim = comp.getPreferredDimension(ug.getStringBounder());
 		final Area area = new Area(dim.getWidth(), y2 - y1);
-		comp.drawU(ug.apply(new UTranslate(0, y1)), area, context);
+		comp.drawU(ug.apply(UTranslate.dy(y1)), area, context);
 	}
 
 	public void delayOn(double y, double height) {
