@@ -286,14 +286,14 @@ public class Rose {
 				smallFont = smallFont.changeColor(smallColor);
 			}
 			return new ComponentRoseGroupingHeader(styles == null ? null : styles[0], styles == null ? null : styles[1],
-					param.getBackgroundColor(true), getSymbolContext(stereotype, param, ColorParam.sequenceGroupBorder),
+					param.getBackgroundColor(), getSymbolContext(stereotype, param, ColorParam.sequenceGroupBorder),
 					bigFont, smallFont, stringsToDisplay, param, roundCorner);
 		}
 		if (type == ComponentType.GROUPING_ELSE) {
 			return new ComponentRoseGroupingElse(styles == null ? null : styles[0],
 					getHtmlColor(param, stereotype, ColorParam.sequenceGroupBorder),
 					getUFont2(param, FontParam.SEQUENCE_GROUP), stringsToDisplay.get(0), param,
-					param.getBackgroundColor(true), roundCorner);
+					param.getBackgroundColor(), roundCorner);
 		}
 		if (type == ComponentType.GROUPING_SPACE) {
 			return new ComponentRoseGroupingSpace(7);
