@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -41,21 +41,35 @@ import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.SkinParamUtils;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.cucadiagram.ILeaf;
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.svek.AbstractEntityImage;
 import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.ugraphic.Shadowable;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
-import net.sourceforge.plantuml.ugraphic.UChangeColor;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.URectangle;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.HColorNone;
 
 public class EntityImageSynchroBar extends AbstractEntityImage {
 
-	public EntityImageSynchroBar(ILeaf entity, ISkinParam skinParam) {
+	// private final SName styleName;
+
+	public EntityImageSynchroBar(ILeaf entity, ISkinParam skinParam, SName styleName) {
 		super(entity, skinParam);
+		// this.styleName = styleName;
+	}
+
+	public StyleSignature getDefaultStyleDefinitionBar() {
+		// return StyleSignature.of(SName.root, SName.element, styleName,
+		// SName.activityBar);
+		return StyleSignature.of(SName.root, SName.element, SName.activityBar);
 	}
 
 	public Dimension2D calculateDimension(StringBounder stringBounder) {
@@ -68,12 +82,20 @@ public class EntityImageSynchroBar extends AbstractEntityImage {
 	final public void drawU(UGraphic ug) {
 		final Dimension2D dim = calculateDimension(ug.getStringBounder());
 		final Shadowable rect = new URectangle(dim.getWidth(), dim.getHeight());
-		if (getSkinParam().shadowing()) {
-			rect.setDeltaShadow(4);
+		double shadowing = 0;
+		if (getSkinParam().shadowing(getEntity().getStereotype())) {
+			shadowing = 4;
 		}
-		ug.apply(new UChangeColor(null))
-				.apply(new UChangeBackColor(SkinParamUtils
-						.getColor(getSkinParam(), ColorParam.activityBar, getStereo()))).draw(rect);
+		HColor color = SkinParamUtils.getColor(getSkinParam(), getStereo(), ColorParam.activityBar);
+		if (UseStyle.useBetaStyle()) {
+			final Style style = getDefaultStyleDefinitionBar().with(getEntity().getStereotype())
+					.getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+			color = style.value(PName.BackGroundColor).asColor(getSkinParam().getThemeStyle(),
+					getSkinParam().getIHtmlColorSet());
+			shadowing = style.value(PName.Shadowing).asDouble();
+		}
+		rect.setDeltaShadow(shadowing);
+		ug.apply(new HColorNone()).apply(color.bg()).draw(rect);
 	}
 
 	public ShapeType getShapeType() {
