@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -40,6 +40,7 @@ import java.util.Collections;
 import java.util.List;
 
 import net.sourceforge.plantuml.OptionFlags;
+import net.sourceforge.plantuml.windowsdot.WindowsDotArchive;
 
 public enum License {
 
@@ -77,7 +78,7 @@ public enum License {
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the MIT License.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the MIT), then the generated images are logically covered");
@@ -109,7 +110,7 @@ public enum License {
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the Eclipse Public License.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the EPL), then the generated images are logically covered");
@@ -149,7 +150,7 @@ public enum License {
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the Eclipse Public License.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the BSD), then the generated images are logically covered");
@@ -177,7 +178,7 @@ public enum License {
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the Apache license.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the Apache), then the generated images are logically covered");
@@ -195,17 +196,15 @@ public enum License {
 		text.add("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public");
 		text.add("License for more details.");
 		text.add(" ");
-		text.add("You should have received a copy of the GNU General Public");
-		text.add("License along with this library; if not, write to the Free Software");
-		text.add("Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,");
-		text.add("USA.");
+		text.add("You should have received a copy of the GNU General Public License");
+		text.add("along with this library.  If not, see <https://www.gnu.org/licenses/>.");
 		text.add(" ");
 		addSupplementary(licenseInfo, text);
 		text.add("the GPL license.");
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the GPL license.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the GPL), then the generated images are logically covered");
@@ -223,17 +222,15 @@ public enum License {
 		text.add("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public");
 		text.add("License for more details.");
 		text.add(" ");
-		text.add("You should have received a copy of the GNU General Public");
-		text.add("License along with this library; if not, write to the Free Software");
-		text.add("Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,");
-		text.add("USA.");
+		text.add("You should have received a copy of the GNU General Public License");
+		text.add("along with this library.  If not, see <https://www.gnu.org/licenses/>.");
 		text.add(" ");
 		addSupplementary(licenseInfo, text);
 		text.add("the GPL license.");
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the GPL license.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("also this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the GPL), then the generated images are logically covered");
@@ -251,17 +248,15 @@ public enum License {
 		text.add("or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public");
 		text.add("License for more details.");
 		text.add(" ");
-		text.add("You should have received a copy of the GNU Lesser General Public");
-		text.add("License along with this library; if not, write to the Free Software");
-		text.add("Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,");
-		text.add("USA.");
+		text.add("You should have received a copy of the GNU Lesser General Public License");
+		text.add("along with this library.  If not, see <https://www.gnu.org/licenses/>.");
 		text.add(" ");
 		addSupplementary(licenseInfo, text);
 		text.add("the LGPL license.");
 		text.add(" ");
 		text.add("The generated images can then be used without any reference to the LGPL license.");
 		text.add("It is not even necessary to stipulate that they have been generated with PlantUML,");
-		text.add("although this will be appreciate by PlantUML team.");
+		text.add("although this will be appreciated by the PlantUML team.");
 		text.add(" ");
 		text.add("There is an exception : if the textual description in PlantUML language is also covered");
 		text.add("by a license (like the LGPL), then the generated images are logically covered");
@@ -273,6 +268,7 @@ public enum License {
 			text.add("PlantUML can occasionally display sponsored or advertising messages. Those");
 			text.add("messages are usually generated on welcome or error images and never on");
 			text.add("functional diagrams.");
+			text.add("See https://plantuml.com/professional if you want to remove them");
 			text.add(" ");
 		}
 		text.add("Images (whatever their format : PNG, SVG, EPS...) generated by running PlantUML");
@@ -280,57 +276,79 @@ public enum License {
 		text.add("textual description in PlantUML language). Those images are not covered by");
 	}
 
-	private List<String> getHeaderStart(LicenseInfo licenseInfo) {
-		final List<String> text = new ArrayList<String>();
+	private void header1(final List<String> text, LicenseInfo licenseInfo) {
 		if (licenseInfo.isNone()) {
-			text.add("========================================================================");
-			text.add("PlantUML : a free UML diagram generator");
-			text.add("========================================================================");
-			text.add(" ");
+			text.add("+=======================================================================");
+			text.add("| ");
+			text.add("|      PlantUML : a free UML diagram generator");
+			text.add("| ");
+			text.add("+=======================================================================");
 		} else {
-			text.add("========================================================================");
-			text.add("This is PlantUML Professional Edition");
-			text.add("========================================================================");
+			text.add("+=======================================================================");
+			text.add("| ");
+			text.add("|      PlantUML Professional Edition");
+			text.add("| ");
+			text.add("+=======================================================================");
 			addLicenseInfo(text, licenseInfo);
-			text.add("========================================================================");
-			text.add(" ");
+			text.add("+=======================================================================");
 		}
-		text.add("(C) Copyright 2009-2017, Arnaud Roques");
+	}
+
+	private void header2(final List<String> text, LicenseInfo licenseInfo, boolean withQrcode) {
 		text.add(" ");
-		text.add("Project Info:  http://plantuml.com");
+		text.add("(C) Copyright 2009-2020, Arnaud Roques");
 		text.add(" ");
+		text.add("Project Info:  https://plantuml.com");
+		text.add(" ");
+
 		if (licenseInfo.isValid() == false) {
 			text.add("If you like this project or if you find it useful, you can support us at:");
 			text.add(" ");
-			text.add("http://plantuml.com/patreon (only 1$ per month!)");
-			text.add("http://plantuml.com/paypal");
-			text.add(" ");
+			text.add("https://plantuml.com/patreon (only 1$ per month!)");
+			text.add("https://plantuml.com/liberapay (only 1\u20ac per month!)");
+			text.add("https://plantuml.com/paypal");
+			if (withQrcode) {
+				text.add(
+						"\t<qrcode:http://plantuml.com/patreon>\t\t<qrcode:http://plantuml.com/lp>\t\t<qrcode:http://plantuml.com/paypal>");
+			} else {
+				text.add("");
+				text.add(" ");
+			}
 		}
-		return text;
 	}
 
 	public static void addLicenseInfo(final List<String> text, LicenseInfo licenseInfo) {
-		text.add("LICENSED TO : " + licenseInfo.getOwner());
-		text.add("EXPIRATION DATE : " + DateFormat.getDateInstance().format(licenseInfo.getExpirationDate()));
-		if (licenseInfo.hasExpired()) {
-			text.add("<i>Warning: Your license has expired.");
+		if (licenseInfo.getLicenseType() == LicenseType.NAMED) {
+			text.add("| ");
+			text.add("|      LICENSED TO : " + licenseInfo.getOwner());
+			text.add(
+					"|      EXPIRATION DATE : " + DateFormat.getDateInstance().format(licenseInfo.getExpirationDate()));
+			text.add("|  ");
+		} else if (licenseInfo.getLicenseType() == LicenseType.DISTRIBUTOR) {
+			text.add("|  ");
+			text.add("|      DISTRIBUTED BY : " + licenseInfo.getOwner());
+			text.add("|  ");
+		}
+		if (licenseInfo.getLicenseType() != LicenseType.UNKNOWN && licenseInfo.hasExpired()) {
+			text.add("|      <i>Warning: Your license has expired.");
+			text.add("|  ");
 		}
 	}
 
-	public List<String> getJavaHeader() {
-		final List<String> h = new ArrayList<String>();
+	public List<String> getJavaHeader(List<String> contributors) {
+		final List<String> h = new ArrayList<>();
 		h.add("/* ========================================================================");
 		h.add(" * PlantUML : a free UML diagram generator");
 		h.add(" * ========================================================================");
 		h.add(" *");
-		h.add(" * (C) Copyright 2009-2017, Arnaud Roques");
+		h.add(" * (C) Copyright 2009-2020, Arnaud Roques");
 		h.add(" *");
-		h.add(" * Project Info:  http://plantuml.com");
+		h.add(" * Project Info:  https://plantuml.com");
 		h.add(" * ");
 		h.add(" * If you like this project or if you find it useful, you can support us at:");
 		h.add(" * ");
-		h.add(" * http://plantuml.com/patreon (only 1$ per month!)");
-		h.add(" * http://plantuml.com/paypal");
+		h.add(" * https://plantuml.com/patreon (only 1$ per month!)");
+		h.add(" * https://plantuml.com/paypal");
 		h.add(" * ");
 		h.add(" * This file is part of PlantUML.");
 		h.add(" *");
@@ -345,10 +363,8 @@ public enum License {
 			h.add(" * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public");
 			h.add(" * License for more details.");
 			h.add(" *");
-			h.add(" * You should have received a copy of the GNU Lesser General Public");
-			h.add(" * License along with this library; if not, write to the Free Software");
-			h.add(" * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,");
-			h.add(" * USA.");
+			h.add(" * You should have received a copy of the GNU General Public License");
+			h.add(" * along with this library.  If not, see <https://www.gnu.org/licenses/>.");
 			h.add(" *");
 		} else if (this == License.GPLV2) {
 			h.add(" * PlantUML is free software; you can redistribute it and/or modify it");
@@ -361,10 +377,8 @@ public enum License {
 			h.add(" * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public");
 			h.add(" * License for more details.");
 			h.add(" *");
-			h.add(" * You should have received a copy of the GNU General Public");
-			h.add(" * License along with this library; if not, write to the Free Software");
-			h.add(" * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,");
-			h.add(" * USA.");
+			h.add(" * You should have received a copy of the GNU General Public License");
+			h.add(" * along with this library.  If not, see <https://www.gnu.org/licenses/>.");
 			h.add(" *");
 		} else if (this == License.APACHE) {
 			h.add(" * Licensed under the Apache License, Version 2.0 (the \"License\");");
@@ -447,13 +461,34 @@ public enum License {
 		}
 		h.add(" *");
 		h.add(" * Original Author:  Arnaud Roques");
+		h.addAll(contributors);
 		h.add(" */");
 		return Collections.unmodifiableList(h);
 	}
 
-	public List<String> getText() {
-		final LicenseInfo licenseInfo = LicenseInfo.retrieveSlow();
-		final List<String> text = getHeaderStart(licenseInfo);
+	public List<String> getTextFull() {
+		final LicenseInfo licenseInfo = LicenseInfo.retrieveQuick();
+		final List<String> text = new ArrayList<>();
+		header1(text, licenseInfo);
+		header2(text, licenseInfo, false);
+		end3(text, licenseInfo);
+		return text;
+	}
+
+	public List<String> getText1(LicenseInfo licenseInfo) {
+		final List<String> text = new ArrayList<>();
+		header1(text, licenseInfo);
+		return text;
+	}
+
+	public List<String> getText2(LicenseInfo licenseInfo) {
+		final List<String> text = new ArrayList<>();
+		header2(text, licenseInfo, true);
+		end3(text, licenseInfo);
+		return text;
+	}
+
+	private void end3(final List<String> text, final LicenseInfo licenseInfo) {
 		if (this == License.GPL) {
 			addGpl(licenseInfo, text);
 		} else if (this == License.GPLV2) {
@@ -474,9 +509,18 @@ public enum License {
 		if (OptionFlags.getInstance().isEnableStats()) {
 			text.add(" ");
 			text.add("This version of PlantUML records general local statistics about usage.");
-			text.add("(more info on http://plantuml.com/statistics-report)");
+			text.add("(more info on https://plantuml.com/statistics-report)");
 		}
 		text.add(" ");
+		if (WindowsDotArchive.getInstance().isThereArchive()) {
+			text.add("This distribution bundles a minimal set of GraphViz files and may install them");
+			text.add(" if needed in the local temporary directory.");
+		} else {
+			text.add("This is the IGY distribution (Install GraphViz by Yourself).");
+			text.add("You have to install GraphViz and to setup the GRAPHVIZ_DOT environment variable");			
+		}
+		text.add("(see https://plantuml.com/graphviz-dot )");
+		text.add(" ");
 		text.add("Icons provided by OpenIconic :  https://useiconic.com/open");
 		text.add("Archimate sprites provided by Archi :  http://www.archimatetool.com");
 		text.add("Stdlib AWS provided by https://github.com/milo-minderbinder/AWS-PlantUML");
@@ -485,7 +529,7 @@ public enum License {
 		text.add("ASCIIMathML (c) David Lippman http://www.pierce.ctc.edu/dlippman");
 		text.add("CafeUndZopfli ported by Eugene Klyuchnikov https://github.com/eustas/CafeUndZopfli");
 		text.add("Brotli (c) by the Brotli Authors https://github.com/google/brotli");
+		text.add("Themes (c) by Brett Schwarz https://github.com/bschwarz/puml-themes");
 		text.add(" ");
-		return text;
 	}
 }
